@@ -279,6 +279,7 @@ bool studio::App::use_colorspace_gamma=true;
 #endif  // SINGLE THREADED
 bool studio::App::restrict_radius_ducks=true;
 bool studio::App::resize_imported_images=false;
+bool studio::App::enable_experimental_features=false;
 String studio::App::custom_filename_prefix(DEFAULT_FILENAME_PREFIX);
 int studio::App::preferred_x_size=480;
 int studio::App::preferred_y_size=270;
@@ -557,6 +558,11 @@ public:
 				value=strprintf("%i",(int)App::resize_imported_images);
 				return true;
 			}
+			if(key=="enable_experimental_features")
+			{
+				value=strprintf("%i",(int)App::enable_experimental_features);
+				return true;
+			}
 			if(key=="browser_command")
 			{
 				value=App::browser_command;
@@ -684,6 +690,12 @@ public:
 				App::resize_imported_images=i;
 				return true;
 			}
+			if(key=="enable_experimental_features")
+			{
+				int i(atoi(value.c_str()));
+				App::enable_experimental_features=i;
+				return true;
+			}
 			if(key=="browser_command")
 			{
 				App::browser_command=value;
@@ -761,6 +773,7 @@ public:
 		ret.push_back("auto_recover_backup_interval");
 		ret.push_back("restrict_radius_ducks");
 		ret.push_back("resize_imported_images");
+		ret.push_back("enable_experimental_features");
 		ret.push_back("browser_command");
 		ret.push_back("custom_filename_prefix");
 		ret.push_back("preferred_x_size");
@@ -855,6 +868,9 @@ init_ui_manager()
 	DEFINE_ACTION("mask-radius-ducks", _("Show Radius Handles"));
 	DEFINE_ACTION("mask-width-ducks", _("Show Width Handles"));
 	DEFINE_ACTION("mask-angle-ducks", _("Show Angle Handles"));
+	DEFINE_ACTION("mask-bone-setup-ducks", _("Show Bone Setup Handles"));
+	DEFINE_ACTION("mask-bone-recursive-ducks", _("Show Recursive Scale Bone Handles"));
+	DEFINE_ACTION("mask-bone-ducks", _("Next Bone Handles"));
 	DEFINE_ACTION("mask-widthpoint-position-ducks", _("Show WidthPoints Position Handles"));
 	DEFINE_ACTION("quality-00", _("Use Parametric Renderer"));
 	DEFINE_ACTION("quality-01", _("Use Quality Level 1"));
@@ -902,7 +918,7 @@ init_ui_manager()
 	DEFINE_ACTION("amount-inc", _("Increase Amount"));
 	DEFINE_ACTION("amount-dec", _("Decrease Amount"));
 
-
+  //Layout the actions in the main menu (caret menu, right click on canvas menu) and toolbar:
     Glib::ustring ui_info =
 "<ui>"
 "	<popup name='menu-toolbox' action='menu-toolbox'>"
@@ -956,6 +972,9 @@ init_ui_manager()
 "			<menuitem action='mask-radius-ducks' />"
 "			<menuitem action='mask-width-ducks' />"
 "			<menuitem action='mask-angle-ducks' />"
+"			<menuitem action='mask-bone-setup-ducks' />"
+"			<menuitem action='mask-bone-recursive-ducks' />"
+"			<menuitem action='mask-bone-ducks' />"
 "			<menuitem action='mask-widthpoint-position-ducks' />"
 "		</menu>"
 "		<menu action='menu-preview-quality'>"
@@ -1030,6 +1049,9 @@ init_ui_manager()
 "		<menuitem action='amount-dec'/>"
 "	</menu>"
 "	<menu action='menu-keyframe'>"
+"		<menuitem action='action-KeyframeAdd'/>"
+"		<menuitem action='action-KeyframeDuplicate'/>"
+"		<menuitem action='action-KeyframeRemove'/>"
 "		<menuitem action='keyframe-properties'/>"
 "	</menu>"
 "	<menu action='menu-plugins'>"
@@ -1145,6 +1167,9 @@ init_ui_manager()
 	ACCEL("<Mod1>4",													"<Actions>/canvasview/mask-radius-ducks"				);
 	ACCEL("<Mod1>5",													"<Actions>/canvasview/mask-width-ducks"				);
 	ACCEL("<Mod1>6",													"<Actions>/canvasview/mask-angle-ducks"				);
+	ACCEL("<Mod1>7",													"<Actions>/canvasview/mask-bone-setup-ducks"			);
+	ACCEL("<Mod1>8",													"<Actions>/canvasview/mask-bone-recursive-ducks"		);
+	ACCEL("<Mod1>9",													"<Actions>/canvasview/mask-bone-ducks"				);
 	ACCEL("<Mod1>5",													"<Actions>/canvasview/mask-widthpoint-position-ducks"				);
 	ACCEL2(Gtk::AccelKey(GDK_Page_Up,Gdk::SHIFT_MASK,					"<Actions>/action_group_layer_action_manager/action-LayerRaise"				));
 	ACCEL2(Gtk::AccelKey(GDK_Page_Down,Gdk::SHIFT_MASK,					"<Actions>/action_group_layer_action_manager/action-LayerLower"				));
@@ -1181,6 +1206,7 @@ init_ui_manager()
 	ACCEL("Home",														"<Actions>/canvasview/seek-begin"						);
 	ACCEL("End",														"<Actions>/canvasview/seek-end"						);
 
+
 #undef ACCEL
 #undef ACCEL2
 }
@@ -1191,12 +1217,12 @@ init_ui_manager()
 
 /* === M E T H O D S ======================================================= */
 
-App::App(int *argc, char ***argv):
+App::App(const synfig::String& basepath, int *argc, char ***argv):
 	Gtk::Main(argc,argv),
-	IconController(etl::dirname((*argv)[0]))
+	IconController(basepath)
 {
-	app_base_path_=etl::dirname(etl::dirname((*argv)[0]));
 
+	app_base_path_=etl::dirname(basepath);
 
 	ui_interface_=new GlobalUIInterface();
 
@@ -1244,7 +1270,7 @@ App::App(int *argc, char ***argv):
 	SuperCallback studio_init_cb(splash_screen.get_callback(),9000,10000,10000);
 
 	// Initialize the Synfig library
-	try { synfigapp_main=etl::smart_ptr<synfigapp::Main>(new synfigapp::Main(etl::dirname((*argv)[0]),&synfig_init_cb)); }
+	try { synfigapp_main=etl::smart_ptr<synfigapp::Main>(new synfigapp::Main(basepath,&synfig_init_cb)); }
 	catch(std::runtime_error x)
 	{
 		get_ui_interface()->error(strprintf("%s\n\n%s", _("Failed to initialize synfig!"), x.what()));
@@ -1261,6 +1287,14 @@ App::App(int *argc, char ***argv):
 
 	try
 	{
+		
+		
+		
+		// Try to load settings early to get access to some important
+		// values, like "enable_experimental_features".
+		studio_init_cb.task(_("Loading Basic Settings..."));
+		load_settings("pref.enable_experimental_features");
+		
 		studio_init_cb.task(_("Loading Plugins..."));
 		
 		std::string pluginsprefix;
@@ -1364,8 +1398,35 @@ App::App(int *argc, char ***argv):
 		studio_init_cb.task(_("Init DeviceTracker..."));
 		device_tracker=new studio::DeviceTracker();
 
-		studio_init_cb.task(_("Init Tools..."));
+		//Init Tools...was here
 
+		studio_init_cb.task(_("Init ModPalette..."));
+		module_list_.push_back(new ModPalette()); module_list_.back()->start();
+
+		studio_init_cb.task(_("Init Setup Dialog..."));
+		dialog_setup=new studio::Dialog_Setup();
+
+		studio_init_cb.task(_("Init Input Dialog..."));
+		dialog_input=new Gtk::InputDialog();
+		dialog_input->get_close_button()->signal_clicked().connect( sigc::mem_fun( *dialog_input, &Gtk::InputDialog::hide ) );
+		dialog_input->get_save_button()->signal_clicked().connect( sigc::mem_fun( *device_tracker, &DeviceTracker::save_preferences) );
+		
+		studio_init_cb.task(_("Init auto recovery..."));
+		auto_recover=new AutoRecover();
+
+		studio_init_cb.amount_complete(9250,10000);
+		studio_init_cb.task(_("Loading Settings..."));
+		load_accel_map();
+		if (!load_settings())
+		{
+			gamma.set_gamma(1.0/2.2);
+			reset_initial_window_configuration();
+		}
+		load_file_window_size();
+
+		// Init Tools must be done after load_accel_map() : accelerators keys
+		// are displayed in toolbox labels
+		studio_init_cb.task(_("Init Tools..."));
 		/* editing tools */
 		state_manager->add_state(&state_normal);
 		state_manager->add_state(&state_smooth_move);
@@ -1392,23 +1453,7 @@ App::App(int *argc, char ***argv):
 		if(!getenv("SYNFIG_DISABLE_SKETCH" )) state_manager->add_state(&state_sketch);
 		state_manager->add_state(&state_zoom);
 
-		studio_init_cb.task(_("Init ModPalette..."));
-		module_list_.push_back(new ModPalette()); module_list_.back()->start();
 
-		studio_init_cb.task(_("Init Setup Dialog..."));
-		dialog_setup=new studio::Dialog_Setup();
-
-		studio_init_cb.task(_("Init Input Dialog..."));
-		dialog_input=new Gtk::InputDialog();
-		dialog_input->get_close_button()->signal_clicked().connect( sigc::mem_fun( *dialog_input, &Gtk::InputDialog::hide ) );
-		dialog_input->get_save_button()->signal_clicked().connect( sigc::mem_fun( *device_tracker, &DeviceTracker::save_preferences) );
-
-		studio_init_cb.task(_("Init auto recovery..."));
-		auto_recover=new AutoRecover();
-
-		studio_init_cb.amount_complete(9250,10000);
-		studio_init_cb.task(_("Loading Settings..."));
-		load_settings();
 		device_tracker->load_preferences();
 		// If the default bline width is modified before focus a canvas
 		// window, the Distance widget doesn't understand the given value
@@ -1423,7 +1468,7 @@ App::App(int *argc, char ***argv):
 		studio_init_cb.amount_complete(9900,10000);
 
 		bool opened_any = false;
-		if(auto_recover->recovery_needed())
+		if (!getenv("SYNFIG_DISABLE_AUTO_RECOVERY") && auto_recover->recovery_needed())
 		{
 			splash_screen.hide();
 			if (get_ui_interface()->confirmation(_("Crash Recovery"),
@@ -1480,6 +1525,32 @@ App::App(int *argc, char ***argv):
 		dock_manager->show_all_dock_dialogs();
 
 		toolbox->present();
+
+		splash_screen.hide();
+
+		String warnings;
+		if (App::enable_experimental_features) {
+			warnings += _("EXPERIMENTAL FEATURES:");
+			warnings += "\n\n";
+			warnings += _("This version have following experimental features enabled:");
+			warnings += "\n";
+			warnings += String("   * ")+_("Skeleton Layer");
+			warnings += "\n\n";
+			warnings += _("The experimental features are NOT intended for production use. It is quite posiible their functionality will change in the future versions, which can break compatibility for your files. Use for testing purposes only.");
+			warnings += "\n\n";
+			warnings += _("You can disable experimental features on the \"Misc\" tab of Setup dialog.");
+		}
+#ifdef WIN32
+		if (warnings!="")
+			warnings += "\n\n";
+		warnings += _("BUG WARNING:");
+		warnings += "\n\n";
+		warnings += _("This version of Synfig Studio have a bug, which can cause computer to hang/freeze when you resize the canvas window. If you got affected by this issue, consider pressing ALT+TAB to unfreeze your system and get it back to the working state.");
+		warnings += "\n\n";
+		warnings += _("Please accept our apologies for inconvenience, we hope to get this issue resolved in the future versions.");
+#endif
+		if (warnings!="")
+			dialog_warning_blocking(_("Warning"), warnings);
 	}
 	catch(String x)
 	{
@@ -1748,8 +1819,25 @@ App::save_settings()
 	}
 }
 
+bool
+App::load_settings(const synfig::String& key_filter)
+{
+	bool ret=false;
+	try
+	{
+		synfig::ChangeLocale change_locale(LC_NUMERIC, "C");
+		std::string filename=get_config_file("settings");
+		ret=synfigapp::Main::settings().load_from_file(filename, key_filter);
+	}
+	catch(...)
+	{
+		synfig::warning("Caught exception when attempting to load settings.");
+	}
+	return ret;
+}
+
 void
-App::load_settings()
+App::load_accel_map()
 {
 	try
 	{
@@ -1758,6 +1846,19 @@ App::load_settings()
 			std::string filename=get_config_file("accelrc");
 			Gtk::AccelMap::load(filename);
 		}
+	}
+	catch(...)
+	{
+		synfig::warning("Caught exception when attempting to load accel map settings.");
+	}
+}
+
+void
+App::load_file_window_size()
+{
+	try
+	{
+		synfig::ChangeLocale change_locale(LC_NUMERIC, "C");
 		{
 			bool window_size_broken = false;
 
@@ -1799,21 +1900,11 @@ App::load_settings()
 				recent_files_window_size.resize(recent_files.size());
 			}
 		}
-		std::string filename=get_config_file("settings");
-		if(!synfigapp::Main::settings().load_from_file(filename))
-		{
-			//std::string filename=Glib::locale_from_utf8(Glib::build_filename(Glib::get_home_dir(),".synfigrc"));
-			//if(!synfigapp::Main::settings().load_from_file(filename))
-			{
-				gamma.set_gamma(1.0/2.2);
-				reset_initial_window_configuration();
-			}
-		}
 
 	}
 	catch(...)
 	{
-		synfig::warning("Caught exception when attempting to load settings.");
+		synfig::warning("Caught exception when attempting to load window settings.");
 	}
 }
 
@@ -1872,12 +1963,11 @@ App::reset_initial_window_configuration()
 	int h_ysize=rect.get_height()*hpanel_height/100.0;
 	std::string h_pos(strprintf("%d %d", h_xpos, h_ypos));
 	std::string h_size(strprintf("%d %d", h_xsize, h_ysize));
-	int v_dock1 = rect.get_height()*vdock*0.8/100.0;
-	int v_dock2 = rect.get_height()*vdock*0.6/100.0;
-	int v_dock3 = rect.get_height()*vdock*1.1/100.0;
+	int v_dock1 = rect.get_height()*vdock*1.0/100.0;
+	int v_dock2 = rect.get_height()*vdock*1.1/100.0;
 	int h_dock = rect.get_width()*hdock/100.0;
 //Contents size
-	std::string v_contents(strprintf("%d %d %d", v_dock1, v_dock2, v_dock3));
+	std::string v_contents(strprintf("%d %d", v_dock1, v_dock2));
 	std::string h_contents(strprintf("%d", h_dock));
 // Tool Box position
 	std::string tbox_pos(strprintf("%d %d", rect.get_x(), rect.get_y()));
@@ -1891,7 +1981,7 @@ App::reset_initial_window_configuration()
 	synfig::info("h_sizes: %s", h_size.c_str());
 */
 	synfigapp::Main::settings().set_value("dock.dialog.1.comp_selector","1");
-	synfigapp::Main::settings().set_value("dock.dialog.1.contents","navigator - info pal_edit pal_browse - tool_options history canvases - layers groups");
+	synfigapp::Main::settings().set_value("dock.dialog.1.contents","navigator info pal_edit pal_browse - tool_options history canvases - layers groups");
 	synfigapp::Main::settings().set_value("dock.dialog.1.contents_size",v_contents);
 	synfigapp::Main::settings().set_value("dock.dialog.1.size",v_size);
 	synfigapp::Main::settings().set_value("dock.dialog.1.pos",v_pos);
@@ -1915,6 +2005,7 @@ App::reset_initial_preferences()
 #endif
 	synfigapp::Main::settings().set_value("pref.restrict_radius_ducks","1");
 	synfigapp::Main::settings().set_value("pref.resize_imported_images","0");
+	synfigapp::Main::settings().set_value("pref.enable_experimental_features","0");
 	synfigapp::Main::settings().set_value("pref.custom_filename_prefix",DEFAULT_FILENAME_PREFIX);
 	synfigapp::Main::settings().set_value("pref.preferred_x_size","480");
 	synfigapp::Main::settings().set_value("pref.preferred_y_size","270");
@@ -2180,7 +2271,8 @@ App::dialog_save_file(const std::string &title, std::string &filename, std::stri
 	{
 		file_type_enum = manage(new Widget_Enum());
 		file_type_enum->set_param_desc(ParamDesc().set_hint("enum")
-				.add_enum_value(synfig::RELEASE_VERSION_0_63_05, "0.64.0", strprintf("0.64.0 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_1, "0.64.1", strprintf("0.64.1 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_0, "0.64.0", "0.64.0")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.05", "0.63.05")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.04", "0.63.04")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_03, "0.63.03", "0.63.03")
@@ -2492,12 +2584,15 @@ bool
 App::open_as(std::string filename,std::string as)
 {
 #ifdef WIN32
-    char long_name[1024];
+    size_t buf_size = PATH_MAX - 1;
+    char* long_name = (char*)malloc(buf_size);
+    long_name[0] = '\0';
     if(GetLongPathName(as.c_str(),long_name,sizeof(long_name)));
-	// when called from autorecover.cpp, filename doesn't exist, and so long_name is empty
-	// don't use it if that's the case
-	if (long_name[0] != '\0')
-		as=long_name;
+    // when called from autorecover.cpp, filename doesn't exist, and so long_name is empty
+    // don't use it if that's the case
+    if (long_name[0] != '\0')
+        as=String(long_name);
+    free(long_name);
 #endif
 
 	try
@@ -2579,9 +2674,16 @@ App::new_instance()
 	canvas->rend_desc().set_antialias(1);
 	canvas->rend_desc().set_flags(RendDesc::PX_ASPECT|RendDesc::IM_SPAN);
 	canvas->set_file_name(file_name);
+	canvas->keyframe_list().add(synfig::Keyframe());
 
 	handle<Instance> instance = Instance::create(canvas);
 
+	if (getenv("SYNFIG_AUTO_ADD_SKELETON_LAYER"))
+		instance->find_canvas_view(canvas)->add_layer("skeleton");
+
+	if (getenv("SYNFIG_AUTO_ADD_MOTIONBLUR_LAYER"))
+		instance->find_canvas_view(canvas)->add_layer("MotionBlur");
+
 	if (getenv("SYNFIG_ENABLE_NEW_CANVAS_EDIT_PROPERTIES"))
 		instance->find_canvas_view(canvas)->canvas_properties.present();
 }
