@@ -56,6 +56,11 @@
 #define SKETCH_DIR_PREFERENCE		"sketch_dir"
 #define RENDER_DIR_PREFERENCE		"render_dir"
 
+// uncomment define SINGLE_THREADED to use a single thread, and hopefully get more stability (dooglus) - changed to be default if using windows (Nov 2009 pixelgeek)
+#ifdef WIN32
+#define SINGLE_THREADED
+#endif
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -193,13 +198,14 @@ public:
 	static bool shutdown_in_progress;
 
 	static bool use_colorspace_gamma;
-
+	
 #ifdef SINGLE_THREADED
 	static bool single_threaded;
 #endif
 
 	static bool restrict_radius_ducks;
 	static bool resize_imported_images;
+	static bool enable_experimental_features;
 	
 	static synfigapp::PluginManager plugin_manager;
 	
@@ -275,7 +281,7 @@ private:
 
 public:
 
-	App(int *argc, char ***argv);
+	App(const synfig::String& basepath, int *argc, char ***argv);
 	virtual ~App();
 
 	/*
@@ -293,7 +299,9 @@ public:
 
 	static synfig::String get_base_path();
 	static void save_settings();
-	static void load_settings();
+	static bool load_settings(const synfig::String& key_filter = "");
+	static void load_accel_map();
+	static void load_file_window_size();
 	static void reset_initial_window_configuration();
 	static void reset_initial_preferences();
 
