@@ -125,7 +125,7 @@ AutoRecover::set_timeout(int milliseconds)
 {
 	timeout=milliseconds;
 	auto_backup_connect.disconnect();
-	if(timeout)
+	if(timeout && !getenv("SYNFIG_DISABLE_AUTO_SAVE"))
 		auto_backup_connect=Glib::signal_timeout().connect(sigc::ptr_fun(&AutoRecover::auto_backup),timeout);
 }
 
@@ -190,6 +190,10 @@ AutoRecover::auto_backup()
 {
 	int pid(0);
 
+#ifdef HAVE_FORK
+#undef HAVE_FORK
+#endif
+
 #ifdef HAVE_FORK
 	pid=fork();
 #endif
