@@ -49,6 +49,7 @@
 #include <synfigapp/selectionmanager.h>
 
 #include <synfig/canvas.h>
+#include <synfig/context.h>
 #include <synfig/string.h>
 #include <synfig/time.h>
 
@@ -136,6 +137,11 @@ class Dock_Layers;
 class Dock_Children;
 class Dock_Keyframes;
 
+/*!	\class studio::CanvasView
+**	\brief \writeme
+**
+**	\writeme
+*/
 class CanvasView : public Gtk::Window, public etl::shared_object
 {
 	friend class UniversalScrubber;
@@ -205,6 +211,7 @@ private:
 
 	etl::loose_handle<Instance> instance_;
 	etl::handle<synfigapp::CanvasInterface> canvas_interface_;
+	synfig::ContextParams context_params_;
 
 	// DEBUGPOINT_CLASS(3);
 
@@ -358,6 +365,8 @@ private:
 	bool rebuild_ducks_queued;
 	sigc::connection queue_rebuild_ducks_connection;
 
+	Glib::RefPtr<Gtk::ToggleAction> action_mask_bone_setup_ducks, action_mask_bone_recursive_ducks;
+
 	/*
  -- ** -- P U B L I C   D A T A -----------------------------------------------
 	*/
@@ -424,6 +433,10 @@ private:
 
 	void refresh_rend_desc();
 
+	void mask_bone_ducks();
+
+	//! Constructor Helper - Create the workarea and connect data and signal
+	/*! \see popup_main_menu() */
 	Gtk::Widget *create_work_area();
 
 	Gtk::Widget *create_time_bar();
@@ -479,6 +492,9 @@ public:
 	//std::map<synfig::String,Gtk::Widget*>& tree_view_book() { return tree_view_book_; }
 	//std::map<synfig::String,Gtk::Widget*>& ext_widget_book() { return tree_view_book_; }
 
+	//! Pop up menu for the main menu and the caret menu (not tools and not the bezier ones).
+	/*! Signal handler for work_area->signal_popup_menu */
+	/*! \see create_work_area(), popup_param_menu(), popup_param_menu_bezier() */
 	void popup_main_menu();
 
 	Smach& get_smach() { return smach_; }
@@ -491,6 +507,10 @@ public:
 
 	virtual ~CanvasView();
 
+	const synfig::ContextParams& get_context_params()const { return context_params_; }
+
+	void set_context_params(const synfig::ContextParams &x) { context_params_ = x; }
+
 	void set_mode(Mode x) { canvas_interface()->set_mode(x); }
 
 	Mode get_mode()const { return canvas_interface()->get_mode(); }
@@ -603,7 +623,7 @@ public:
 	//! Hides the time bar
 	void hide_timebar();
 
-	//t Enables or disables interaction with the timebar
+	//! Enables or disables interaction with the timebar
 	void set_sensitive_timebar(bool sensitive);
 
 	void time_zoom_in();
@@ -718,6 +738,7 @@ private:
 
 	void on_meta_data_changed();
 
+	//! Keyboard event dispatcher following window priority
 	bool on_key_press_event(GdkEventKey* event);
 	bool focused_widget_has_priority(Gtk::Widget * focused);
 
