@@ -46,6 +46,8 @@
 #include <synfig/time.h>
 #include <algorithm>
 
+#include "app.h"
+
 /* === M A C R O S ========================================================= */
 #ifndef DEFAULT_PREDEFINED_SIZE
 #define DEFAULT_PREDEFINED_SIZE _("Custom Size")
@@ -189,6 +191,7 @@ class Dialog_Setup : public Gtk::Dialog
 
 	Gtk::CheckButton toggle_restrict_radius_ducks;
 	Gtk::CheckButton toggle_resize_imported_images;
+	Gtk::CheckButton toggle_enable_experimental_features;
 
 	Gtk::Entry textbox_browser_command;
 
