@@ -39,6 +39,7 @@
 #include <gtkmm/button.h>
 #include <gtkmm/window.h>
 #include <synfigapp/action.h>
+#include <synfig/interpolation.h>
 
 #include "general.h"
 
@@ -72,6 +73,7 @@ using namespace synfig;
 /* === M E T H O D S ======================================================= */
 
 static Glib::RefPtr<Gdk::Pixbuf> _tree_pixbuf_table_value_type[(int)synfig::ValueBase::TYPE_END];
+static Glib::RefPtr<Gdk::Pixbuf> _tree_pixbuf_table_interpolation[(int)INTERPOLATION_CLAMPED+1];
 
 #ifdef WIN32
 IconController::IconController(const synfig::String& basepath)
@@ -170,6 +172,7 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(reset_colors,"reset_colors_icon."IMAGE_EXT,_("Reset Colors"));
 	INIT_STOCK_ICON(swap_colors,"swap_colors_icon."IMAGE_EXT,_("Swap Colors"));
 	INIT_STOCK_ICON(value_node,"valuenode_icon."IMAGE_EXT,_("ValueNode"));
+	INIT_STOCK_ICON(valuenode_forbidanimation,"valuenode_forbidanimation_icon."IMAGE_EXT,_("ValueNode Forbid Animation"));
 	INIT_STOCK_ICON(about,"about_icon."IMAGE_EXT,_("About"));
 	INIT_STOCK_ICON(rename,"rename_icon."IMAGE_EXT,_("Rename"));
 	INIT_STOCK_ICON(canvas,"canvas_icon."IMAGE_EXT,_("Canvas"));
@@ -225,7 +228,9 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(layer_other_importimage,"layer_other_importimage_icon."IMAGE_EXT,_("Import Image Layer"));
 	INIT_STOCK_ICON(layer_other_pastecanvas,"layer_other_group_icon."IMAGE_EXT,_("Group Layer"));
 	INIT_STOCK_ICON(layer_other_plant,"layer_other_plant_icon."IMAGE_EXT,_("Plant Layer"));
+	INIT_STOCK_ICON(layer_other_stroboscope,"layer_other_stroboscope_icon."IMAGE_EXT,_("Stroboscope Layer"));
 	INIT_STOCK_ICON(layer_other_supersample,"layer_other_supersample_icon."IMAGE_EXT,_("Super Sample Layer"));
+	INIT_STOCK_ICON(layer_other_skeleton,"layer_other_skeleton_icon."IMAGE_EXT,_("Skeleton Layer"));
 	INIT_STOCK_ICON(layer_other_text,"layer_other_text_icon."IMAGE_EXT,_("Text Layer"));
 	INIT_STOCK_ICON(layer_other_timeloop,"layer_other_timeloop_icon."IMAGE_EXT,_("Time Loop Layer"));
 	INIT_STOCK_ICON(layer_other_xorpattern,"layer_other_xorpattern_icon."IMAGE_EXT,_("XOR Pattern Layer"));
@@ -334,12 +339,16 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	for(int i(0);i<(int)ValueBase::TYPE_END;i++)
 		_tree_pixbuf_table_value_type[i]=Gtk::Button().render_icon(value_icon(ValueBase::Type(i)),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 
+	for(int i(0);i<((int)INTERPOLATION_CLAMPED+1);i++)
+		_tree_pixbuf_table_interpolation[i]=Gtk::Button().render_icon(interpolation_icon(Interpolation(i)),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 }
 
 IconController::~IconController()
 {
 	for(int i(0);i<(int)ValueBase::TYPE_END;i++)
 		_tree_pixbuf_table_value_type[i]=Glib::RefPtr<Gdk::Pixbuf>();
+	for(int i(0);i<((int)INTERPOLATION_CLAMPED+1);i++)
+		_tree_pixbuf_table_interpolation[i]=Glib::RefPtr<Gdk::Pixbuf>();
 
 	icon_factory->remove_default();
 }
@@ -444,6 +453,36 @@ studio::value_icon(synfig::ValueBase::Type type)
 		}
 }
 
+Gtk::StockID
+studio::interpolation_icon(synfig::Interpolation type)
+{
+	switch(type)
+	{
+		case INTERPOLATION_TCB:
+			return Gtk::StockID("synfig-interpolation_type_tcb");
+			break;
+		case INTERPOLATION_CONSTANT:
+			return Gtk::StockID("synfig-interpolation_type_const");
+			break;
+		case INTERPOLATION_LINEAR:
+			return Gtk::StockID("synfig-interpolation_type_linear");
+			break;
+		case INTERPOLATION_HALT:
+			return Gtk::StockID("synfig-interpolation_type_ease");
+			break;
+		case INTERPOLATION_CLAMPED:
+			return Gtk::StockID("synfig-interpolation_type_clamped");
+			break;
+		case INTERPOLATION_MANUAL:
+		case INTERPOLATION_UNDEFINED:
+		case INTERPOLATION_NIL:
+		default:
+			return Gtk::StockID();
+			break;
+	}
+}
+
+
 Gtk::StockID
 studio::valuenode_icon(etl::handle<synfig::ValueNode> value_node)
 {
@@ -464,6 +503,12 @@ studio::get_tree_pixbuf(synfig::ValueBase::Type type)
 	return _tree_pixbuf_table_value_type[int(type)];
 }
 
+Glib::RefPtr<Gdk::Pixbuf>
+studio::get_interpolation_pixbuf(synfig::Interpolation type)
+{
+	return _tree_pixbuf_table_interpolation[int(type)];
+}
+
 #ifdef WIN32
 #define TEMPORARY_DELETE_MACRO DELETE
 #undef DELETE
@@ -583,6 +628,10 @@ studio::layer_icon(const synfig::String &layer)
 		return Gtk::StockID("synfig-layer_other_pastecanvas");
 	else if(layer=="plant")
 		return Gtk::StockID("synfig-layer_other_plant");
+	else if(layer=="stroboscope")
+		return Gtk::StockID("synfig-layer_other_stroboscope");
+	else if(layer=="skeleton")
+		return Gtk::StockID("synfig-layer_other_skeleton");
 	else if(layer=="super_sample")
 		return Gtk::StockID("synfig-layer_other_supersample");
 	else if(layer=="text")
