@@ -214,7 +214,7 @@ studio::Instance::run_plugin(std::string plugin_path)
 			one_moment.show();
 		} else {
 			bool result;
-			result = launcher.execute(plugin_path);
+			result = launcher.execute( plugin_path, App::get_base_path() );
 			if (!result){
 				one_moment.hide();
 				App::dialog_error_blocking(_("Plugin Error"), launcher.get_output());
@@ -884,8 +884,8 @@ Instance::add_actions_to_menu(Gtk::Menu *menu, const synfigapp::Action::ParamLis
 void
 Instance::process_action(synfig::String name, synfigapp::Action::ParamList param_list)
 {
-	//// debug actions
-	// synfig::info("%s:%d process_action: '%s'", __FILE__, __LINE__, name.c_str());
+	if (getenv("SYNFIG_DEBUG_ACTIONS"))
+		synfig::info("%s:%d process_action: '%s'", __FILE__, __LINE__, name.c_str());
 
 	assert(synfigapp::Action::book().count(name));
 
@@ -1008,6 +1008,127 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 
 		parammenu.items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::CONVERT,*convert_menu));
 	}
+	
+	// Interpolation menu: Show it only if
+	// the value description is constant or animated (layer parameter or exported) and not static
+	// and value is not canvas type
+	if (((value_desc.is_const() && !value_desc.get_static()) || value_desc.is_animated())
+	&&
+		value_desc.get_value_type()!= ValueBase::TYPE_CANVAS
+		)
+	{
+		Gtk::Menu *param_interpolation_menu=manage(new Gtk::Menu());
+		synfigapp::Action::ParamList param_list;
+		param_list.add("canvas", get_canvas());
+		param_list.add("value_desc", value_desc);
+		param_list.add("canvas_interface",canvas_interface);
+		/////// Default
+		param_list.add("new_value", INTERPOLATION_UNDEFINED);
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::MenuElem(
+				_("Default"),
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		/////// TCB
+		param_list.add("new_value", INTERPOLATION_TCB);
+		Gtk::Image *image=new Gtk::Image(Gtk::StockID("synfig-interpolation_type_tcb"),Gtk::IconSize::from_name("synfig-small_icon"));
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::ImageMenuElem(
+				_("TCB"),
+				*image,
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		
+		/////// Linear
+		param_list.add("new_value", INTERPOLATION_LINEAR);
+		image=new Gtk::Image(Gtk::StockID("synfig-interpolation_type_linear"),Gtk::IconSize::from_name("synfig-small_icon"));
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::ImageMenuElem(
+				_("Linear"),
+				*image,
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		
+		/////// Ease
+		param_list.add("new_value", INTERPOLATION_HALT);
+		image=new Gtk::Image(Gtk::StockID("synfig-interpolation_type_ease"),Gtk::IconSize::from_name("synfig-small_icon"));
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::ImageMenuElem(
+				_("Ease"),
+				*image,
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		
+		/////// Constant
+		param_list.add("new_value", INTERPOLATION_CONSTANT);
+		image=new Gtk::Image(Gtk::StockID("synfig-interpolation_type_const"),Gtk::IconSize::from_name("synfig-small_icon"));
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::ImageMenuElem(
+				_("Constant"),
+				*image,
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		
+		/////// Ease
+		param_list.add("new_value", INTERPOLATION_CLAMPED);
+		image=new Gtk::Image(Gtk::StockID("synfig-interpolation_type_clamped"),Gtk::IconSize::from_name("synfig-small_icon"));
+		param_interpolation_menu->items().push_back(
+			Gtk::Menu_Helpers::ImageMenuElem(
+				_("Clamped"),
+				*image,
+				sigc::bind(
+					sigc::bind(
+						sigc::mem_fun(*const_cast<studio::Instance*>(this),&studio::Instance::process_action),
+						param_list
+					),
+					"ValueDescSetInterpolation"
+				)
+			)
+		);
+		param_list.erase("new_value");
+		
+		parammenu.items().push_back(Gtk::Menu_Helpers::MenuElem(_("Interpolation"), *param_interpolation_menu));
+	}
 
 	synfigapp::Action::Category categories = synfigapp::Action::CATEGORY_VALUEDESC|synfigapp::Action::CATEGORY_VALUENODE;
 	if (bezier)
