@@ -101,7 +101,7 @@ public:
 	{
 		if(!prev)
 			return false;
-		gamma_filter(surf);
+		gamma_filter(surf, studio::App::gamma);
 		if(cairo_surface_status(surf))
 		{
 			if(cb) cb->error(_("Cairo Surface bad status"));
@@ -249,6 +249,7 @@ void studio::Preview::render()
 		desc.set_w(neww);
 		desc.set_h(newh);
 		desc.set_frame_rate(newfps);
+		desc.set_render_excluded_contexts(false);
 
 		if(overbegin)
 		{
@@ -760,7 +761,7 @@ bool studio::Widget_Preview::redraw(GdkEventExpose */*heh*/)
 		pxnew = px->scale_simple(nw, nh, Gdk::INTERP_NEAREST);
 
 	//except "Fit" or "fit", we need to set size request for scrolled window
-	if (text != _("Fit") & text != "fit")
+	if (text != _("Fit") && text != "fit")
 	{
 		draw_area.set_size_request(nw, nh);
 		dw = draw_area.get_width();
