@@ -54,6 +54,7 @@
 #include <gtkmm/image.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/handlebox.h>
+#include <gtkmm/accelmap.h>
 
 #include <gtkmm/inputdialog.h>
 
@@ -476,6 +477,11 @@ Toolbox::change_state_(const Smach::state_base *state)
 	changing_state_=false;
 }
 
+
+/*! \fn Toolbox::add_state(const Smach::state_base *state)
+ *  \brief Add and connect a toogle button to the toolbox defined by a state
+ *  \param state a const pointer to Smach::state_base
+*/
 void
 Toolbox::add_state(const Smach::state_base *state)
 {
@@ -491,9 +497,15 @@ Toolbox::add_state(const Smach::state_base *state)
 	Gtk::ToggleButton* button;
 	button=manage(new class Gtk::ToggleButton());
 
+	Gtk::AccelKey key;
+	//Have a look to global fonction init_ui_manager() from app.cpp for "accel_path" definition
+	Gtk::AccelMap::lookup_entry ("<Actions>/action_group_state_manager/state-"+name, key);
+	//Gets the accelerator representation for labels
+	Glib::ustring accel_path = key.get_abbrev ();
+
 	icon=manage(new Gtk::Image(stock_item.get_stock_id(),Gtk::IconSize(4)));
 	button->add(*icon);
-	button->set_tooltip_text(stock_item.get_label());
+	button->set_tooltip_text(stock_item.get_label()+" "+accel_path);
 	icon->show();
 	button->show();
 
@@ -636,14 +648,15 @@ bool
 Toolbox::on_key_press_event(GdkEventKey* event)
 {
 	Gtk::Widget* focused_widget = get_focus();
-	if(focused_widget_has_priority(focused_widget))
+	if(focused_widget && focused_widget_has_priority(focused_widget))
 	{
 		if(focused_widget->event((GdkEvent*)event))
 		return true;
 	}
 	else if(Gtk::Window::on_key_press_event(event))
-		return true;
-	else return focused_widget->event((GdkEvent*)event);
+			return true;
+		else
+			if (focused_widget) return focused_widget->event((GdkEvent*)event);
 	return false;
 }
 
