@@ -197,7 +197,7 @@ KeyframeTreeStore::create(etl::loose_handle<synfigapp::CanvasInterface> canvas_i
 void
 KeyframeTreeStore::reset_stamp()
 {
-	stamp_=time(0)+reinterpret_cast<long>(this);
+	stamp_=time(0)+reinterpret_cast<intptr_t>(this);
 }
 
 /*
@@ -904,14 +904,25 @@ KeyframeTreeStore::change_keyframe(synfig::Keyframe keyframe)
 		dump_iterator(row,"change_keyframe,row");
 		row_changed(get_path(row),row);
 
-		// Previous row should be updated too (length value)
-		synfig::Keyframe keyframe_prev = *(get_canvas()->keyframe_list().find_prev(keyframe.get_time(),false));
-		Gtk::TreeRow row_prev(find_row(keyframe_prev));
-		dump_iterator(row_prev,"change_keyframe,row_prev");
-		row_changed(get_path(row_prev),row_prev);
+		// If exist, previous row should be updated too (length value)
+		try
+		{
+			if (new_index != 0)
+			{
+				synfig::Keyframe keyframe_prev = *(get_canvas()->keyframe_list().find_prev(keyframe.get_time(),false));
+				Gtk::TreeRow row_prev(find_row(keyframe_prev));
+				dump_iterator(row_prev,"change_keyframe,row_prev");
+				row_changed(get_path(row_prev),row_prev);
+			}
+		}
+
+		catch(Exception::NotFound x)
+		{
+			g_warning("%s", x.what());
+		}
 	}
 	catch(std::exception x)
 	{
 		g_warning("%s", x.what());
 	}
-}
+}
\ No newline at end of file
