@@ -213,6 +213,7 @@ LayerTree::create_layer_tree()
 		Gtk::CellRendererText* cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
 		column->pack_start(*cellrenderer,false);
 		column->add_attribute(cellrenderer->property_text(), layer_model.label);
+		column->add_attribute(cellrenderer->property_style(), layer_model.style);
 		cellrenderer->signal_edited().connect(sigc::mem_fun(*this, &studio::LayerTree::on_layer_renamed));
 		cellrenderer->property_editable()=true;
 
@@ -319,6 +320,7 @@ LayerTree::create_param_tree()
 		cellrenderer_value->signal_edited().connect(sigc::mem_fun(*this, &studio::LayerTree::on_edited_value));
 		cellrenderer_value->property_value()=synfig::ValueBase();
 		column->add_attribute(cellrenderer_value->property_param_desc(), param_model.param_desc);
+		column->add_attribute(cellrenderer_value->property_value_desc(), param_model.value_desc);
 		column->add_attribute(cellrenderer_value->property_child_param_desc(), param_model.child_param_desc);
 		column->add_attribute(cellrenderer_value->property_inconsistent(),param_model.is_inconsistent);
 		//cellrenderer_value->property_canvas()=canvas_interface->get_canvas(); // Is this line necessary?
@@ -332,12 +334,37 @@ LayerTree::create_param_tree()
 		column->set_reorderable();
 		column->set_resizable();
 	}
+	{
+		// --- F L A G S (static/interpolation) -----------------------------------------
+		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_(" ")) );
+
+		// Set up the interpolation icon cell-renderer to be on the far right
+		Gtk::CellRendererPixbuf* interpolation_icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
+		column->pack_end(*interpolation_icon_cellrenderer,false);
+		column->add_attribute(interpolation_icon_cellrenderer->property_pixbuf(),param_model.interpolation_icon);
+		column->add_attribute(interpolation_icon_cellrenderer->property_visible(), param_model.interpolation_icon_visible);
+
+		// Set up the static icon cell-renderer to be on the far right
+		Gtk::CellRendererPixbuf* static_icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
+		column->pack_end(*static_icon_cellrenderer,false);
+		static_icon_cellrenderer->property_pixbuf()=Gtk::Button().render_icon(Gtk::StockID("synfig-valuenode_forbidanimation"),icon_size);
+		column->add_attribute(static_icon_cellrenderer->property_visible(), param_model.is_static);
+
+		// Finish setting up the column
+		get_param_tree_view().append_column(*column);
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
+		column->set_clickable();
+		column->set_min_width(26);
+		column->set_reorderable();
+		column->set_resizable();
+	}
 	{	// --- T Y P E --------------------------------------------------------
 		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Type")) );
 		Gtk::CellRendererText* text_cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
 		column->pack_start(*text_cellrenderer,false);
 		column->add_attribute(text_cellrenderer->property_text(), param_model.type);
 		text_cellrenderer->property_attributes()=attr_list;
+
 		get_param_tree_view().append_column(*column);
 		column->set_reorderable();
 		column->set_resizable();
@@ -793,7 +820,7 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 			if(!get_layer_tree_view().get_model()->get_iter(path))
 				break;
 
-			Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
+			//Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
 			if(cellrenderer_time_track==column->get_first_cell_renderer())
