@@ -78,6 +78,7 @@ LayerTreeStore::LayerTreeStore(etl::loose_handle<synfigapp::CanvasInterface> can
 
 	// Connect Signals to Terminals
 	canvas_interface()->signal_layer_status_changed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_status_changed));
+	canvas_interface()->signal_layer_exclude_from_rendering_changed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_exclude_from_rendering_changed));
 	canvas_interface()->signal_layer_lowered().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_lowered));
 	canvas_interface()->signal_layer_raised().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_raised));
 	canvas_interface()->signal_layer_removed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_removed));
@@ -254,6 +255,34 @@ LayerTreeStore::get_value_vfunc (const Gtk::TreeModel::iterator& iter, int colum
 		g_value_init(value.gobj(),x.value_type());
 		g_value_copy(x.gobj(),value.gobj());
 	}
+	else if(column==model.exclude_from_rendering.index())
+	{
+		synfig::Layer::Handle layer((*iter)[model.layer]);
+
+		if(!layer)return;
+
+		Glib::Value<bool> x;
+		g_value_init(x.gobj(),x.value_type());
+
+		x.set(layer->get_exclude_from_rendering());
+
+		g_value_init(value.gobj(),x.value_type());
+		g_value_copy(x.gobj(),value.gobj());
+	}
+	else if(column==model.style.index())
+	{
+		synfig::Layer::Handle layer((*iter)[model.layer]);
+
+		if(!layer)return;
+
+		Glib::Value<Pango::Style> x;
+		g_value_init(x.gobj(),x.value_type());
+
+		x.set(layer->get_exclude_from_rendering() ? Pango::STYLE_ITALIC : Pango::STYLE_NORMAL);
+
+		g_value_init(value.gobj(),x.value_type());
+		g_value_copy(x.gobj(),value.gobj());
+	}
 	else if(column==model.icon.index())
 	{
 		synfig::Layer::Handle layer((*iter)[model.layer]);
@@ -345,6 +374,29 @@ LayerTreeStore::set_value_impl(const Gtk::TreeModel::iterator& iter, int column,
 			canvas_interface()->get_instance()->perform_action(action);
 			return;
 		}
+		else if(column==model.exclude_from_rendering.index())
+		{
+			synfig::Layer::Handle layer((*iter)[model.layer]);
+
+			if(!layer)return;
+
+			Glib::Value<bool> x;
+			g_value_init(x.gobj(),model.exclude_from_rendering.type());
+			g_value_copy(value.gobj(),x.gobj());
+
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerSetExcludeFromRendering"));
+
+			if(!action)
+				return;
+
+			action->set_param("canvas",canvas_interface()->get_canvas());
+			action->set_param("canvas_interface",canvas_interface());
+			action->set_param("layer",layer);
+			action->set_param("new_state",bool(x.get()));
+
+			canvas_interface()->get_instance()->perform_action(action);
+			return;
+		}
 		else
 			Gtk::TreeStore::set_value_impl(iter,column, value);
 
@@ -854,6 +906,19 @@ LayerTreeStore::on_layer_status_changed(synfig::Layer::Handle handle,bool /*x*/)
 	}
 }
 
+void
+LayerTreeStore::on_layer_exclude_from_rendering_changed(synfig::Layer::Handle handle,bool /*x*/)
+{
+	Gtk::TreeModel::Children::iterator iter;
+	if(find_layer_row(handle,iter))
+		(*iter)[model.layer]=handle;
+	else
+	{
+		synfig::warning("Couldn't find layer to be excluded/included from/to rendering in layer list. Rebuilding index...");
+		rebuild();
+	}
+}
+
 void
 LayerTreeStore::on_layer_lowered(synfig::Layer::Handle layer)
 {
