@@ -118,6 +118,10 @@ ColorSlider::adjust_color(Type type, synfig::Color &color, float amount)
 bool
 ColorSlider::redraw(GdkEventExpose */*bleh*/)
 {
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> window = get_window();
+	if(!window) return false;
+
 	Color color(color_);
 
 	static const slider_color_func jump_table[int(TYPE_END)] =
@@ -157,7 +161,7 @@ ColorSlider::redraw(GdkEventExpose */*bleh*/)
 
 	Gdk::Rectangle ca(0,0,width,height);
 
-	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(get_window()));
+	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(window));
 	const Color bg1(0.75, 0.75, 0.75);
 	const Color bg2(0.5, 0.5, 0.5);
 	int i;
@@ -175,23 +179,23 @@ ColorSlider::redraw(GdkEventExpose */*bleh*/)
 		if((i*2/height)&1)
 		{
 			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
-			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
+			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
 
 			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
-			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
 		}
 		else
 		{
 			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
-			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
+			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
 
 			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
-			get_window()->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
 		}
 	}
 
 	get_style()->paint_arrow(
-		get_window(),
+		window,
 		(orig_color.get_y()<ARROW_NEGATIVE_THRESHOLD)?Gtk::STATE_SELECTED:Gtk::STATE_ACTIVE,
 		//use light arrow on dark color, and dark arrow on light color , TODO: detect from style which is darkest from SELECTED or ACTIVE
 		Gtk::SHADOW_OUT,
@@ -207,9 +211,9 @@ ColorSlider::redraw(GdkEventExpose */*bleh*/)
 	);
 
 	gc->set_rgb_fg_color(Gdk::Color("#ffffff"));
-	get_window()->draw_rectangle(gc, false, ca.get_x()+1, ca.get_y()+1, width-3, height-3);
+	window->draw_rectangle(gc, false, ca.get_x()+1, ca.get_y()+1, width-3, height-3);
 	gc->set_rgb_fg_color(Gdk::Color("#000000"));
-	get_window()->draw_rectangle(gc, false, ca.get_x(), ca.get_y(), width-1, height-1);
+	window->draw_rectangle(gc, false, ca.get_x(), ca.get_y(), width-1, height-1);
 	return true;
 }
 
