@@ -82,9 +82,16 @@ Widget_Keyframe_List::~Widget_Keyframe_List()
 {
 }
 
+/*! \fn Widget_Keyframe_List::redraw()
+**	\brief Redraw event. Should draw all the keyframes +  the selected + the dragged + disabled
+**  connected on signal_expose_event()
+*/
 bool
 Widget_Keyframe_List::redraw()
 {
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> window = get_window();
+	if(!window) return true;
 
 	const int h(get_height());
 	const int w(get_width());
@@ -94,13 +101,13 @@ Widget_Keyframe_List::redraw()
 	synfig::Time bottom(adj_timescale->get_lower());
 
 	//! The graphic context
-	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(get_window()));
+	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(window));
 	//! A rectangle that defines the drawing area.
 	Gdk::Rectangle area(0,0,w,h);
 
 	//! draw a background
 	gc->set_rgb_fg_color(Gdk::Color("#9d9d9d"));
-	get_window()->draw_rectangle(gc, true, 0, 0, w, h);
+	window->draw_rectangle(gc, true, 0, 0, w, h);
 
 	if(!editable_)
 	{
@@ -112,6 +119,7 @@ Widget_Keyframe_List::redraw()
 	//!Loop all the keyframes
 	synfig::KeyframeList::iterator iter,selected_iter;
 	bool show_selected(false);
+
 	for(iter=kf_list_->begin();iter!=kf_list_->end();iter++)
 	{
 		//!do not draw keyframes out of the widget boundaries
@@ -121,9 +129,15 @@ Widget_Keyframe_List::redraw()
 		if(*iter!=selected_kf)
 		{
 			const int x((int)((float)(iter->get_time()-bottom) * (w/(top-bottom)) ) );
-			get_style()->paint_arrow(get_window(), Gtk::STATE_NORMAL,
-			Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
-			x-h/2+1, 0, h, h );
+			// Change shape for disabled keyframe
+			if (iter->active())
+				get_style()->paint_arrow(window, Gtk::STATE_NORMAL,
+				Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
+				x-h/2+1, 0, h, h );
+			else
+				get_style()->paint_arrow(window, Gtk::STATE_INSENSITIVE,
+				Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_RIGHT, 1,
+				x-h/2+1, 0, h, h );
 		}
 		else
 		{
@@ -140,20 +154,26 @@ Widget_Keyframe_List::redraw()
 		if (!dragging_)
 		{
 			int x((int)((float)(selected_iter->get_time()-bottom) * (w/(top-bottom)) ) );
-			get_style()->paint_arrow(get_window(), Gtk::STATE_SELECTED,
-			Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
-			x-h/2+1, 0, h, h );
+			// Change shape for disabled keyframe
+			if (selected_iter->active())
+				get_style()->paint_arrow(window, Gtk::STATE_NORMAL,
+				Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
+				x-h/2+1, 0, h, h );
+			else
+				get_style()->paint_arrow(window, Gtk::STATE_NORMAL,
+				Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_RIGHT, 1,
+				x-h/2+1, 0, h, h );
 		}
 		// If dragging then show the selected as insensitive and the
 		// dragged as selected
 		else
 		{
 			int x((int)((float)(selected_iter->get_time()-bottom) * (w/(top-bottom)) ) );
-			get_style()->paint_arrow(get_window(), Gtk::STATE_INSENSITIVE,
+			get_style()->paint_arrow(window, Gtk::STATE_INSENSITIVE,
 			Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
 			x-h/2, 0, h, h );
 			x=(int)((float)(dragging_kf_time-bottom) * (w/(top-bottom)) ) ;
-			get_style()->paint_arrow(get_window(), Gtk::STATE_SELECTED,
+			get_style()->paint_arrow(window, Gtk::STATE_SELECTED,
 			Gtk::SHADOW_OUT, area, *this, " ", Gtk::ARROW_DOWN, 1,
 			x-h/2+1, 0, h, h );
 		}
