@@ -61,6 +61,7 @@
 #include "event_layerclick.h"
 #include "widgets/widget_color.h"
 #include <synfig/distance.h>
+#include <synfig/context.h>
 
 #include "workarearenderer/workarearenderer.h"
 #include "workarearenderer/renderer_background.h"
@@ -68,6 +69,7 @@
 #include "workarearenderer/renderer_grid.h"
 #include "workarearenderer/renderer_guides.h"
 #include "workarearenderer/renderer_timecode.h"
+#include "workarearenderer/renderer_bonesetup.h"
 #include "workarearenderer/renderer_ducks.h"
 #include "workarearenderer/renderer_dragbox.h"
 #include "workarearenderer/renderer_bbox.h"
@@ -278,7 +280,7 @@ public:
 		if(cairo_surface_status(tile_surface))
 			return false;
 
-		gamma_filter(tile_surface);
+		gamma_filter(tile_surface, App::gamma);
 		x/=get_tile_w();
 		y/=get_tile_h();
 		int tw(rend_desc().get_w()/get_tile_w());
@@ -299,7 +301,7 @@ public:
 		{
 			cairo_t* cr=cairo_create(workarea->cairo_book[index].surface);
 			cairo_set_source_surface(cr, tile_surface, 0, 0);
-			cairo_paint_with_alpha(cr, 255/(onion_layers-onion_skin_queue.size()+1));
+			cairo_paint_with_alpha(cr, 1.0/(onion_layers-onion_skin_queue.size()+1));
 			cairo_destroy(cr);
 		}
 		
@@ -718,7 +720,7 @@ public:
 	{
 		if(!workarea)
 			return false;
-		gamma_filter(surf);
+		gamma_filter(surf, App::gamma);
 		if(cairo_surface_status(surf))
 		{
 			if(cb) cb->error(_("Cairo Surface bad status"));
@@ -990,7 +992,9 @@ WorkArea::WorkArea(etl::loose_handle<synfigapp::CanvasInterface> canvas_interfac
 	tile_w(TILE_SIZE),
 	tile_h(TILE_SIZE),
 	timecode_width(0),
-	timecode_height(0)
+	timecode_height(0),
+	bonesetup_width(0),
+	bonesetup_height(0)
 {
 	show_guides=true;
 	curr_input_device=0;
@@ -1026,6 +1030,7 @@ WorkArea::WorkArea(etl::loose_handle<synfigapp::CanvasInterface> canvas_interfac
 	insert_renderer(new Renderer_BBox,		399);
 	insert_renderer(new Renderer_Dragbox,	400);
 	insert_renderer(new Renderer_Timecode,	500);
+	insert_renderer(new Renderer_BoneSetup,	501);
 
 	signal_duck_selection_changed().connect(sigc::mem_fun(*this,&studio::WorkArea::queue_draw));
 	signal_strokes_changed().connect(sigc::mem_fun(*this,&studio::WorkArea::queue_draw));
@@ -1853,7 +1858,7 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 			etl::handle<Duck> duck=find_duck(mouse_pos,radius);
 			etl::handle<Bezier> bezier=find_bezier(mouse_pos,radius,&bezier_click_pos);
 
-			Layer::Handle layer(get_canvas()->find_layer(mouse_pos));
+			Layer::Handle layer(get_canvas()->find_layer(get_canvas_view()->get_context_params(),mouse_pos));
 			if(duck)
 			{
 				if(get_selected_ducks().size()<=1)
@@ -2157,7 +2162,7 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 			{
 				if(allow_layer_clicks)
 				{
-					Layer::Handle layer(get_canvas()->find_layer(drag_point));
+					Layer::Handle layer(get_canvas()->find_layer(get_canvas_view()->get_context_params(),drag_point));
 					//if(layer)
 					{
 						if(canvas_view->get_smach().process_event(EventLayerClick(layer,BUTTON_LEFT,mouse_pos,modifier))==Smach::RESULT_OK)
@@ -2594,12 +2599,74 @@ handle2ptr(F func)
 	);
 */
 
+#ifdef SINGLE_THREADED
+/* resize bug workaround */
+gboolean
+WorkArea::__refresh_second_check(gpointer data)
+{
+	WorkArea *work_area(static_cast<WorkArea*>(data));
+	work_area->refresh_second_check();
+	return 0;
+}
+
+void
+WorkArea::refresh_second_check()
+{
+	//resize_timeout_connect.disconnect();
+	int width;
+	int height;
+	canvas_view->get_size(width, height);
+	if (width==old_window_width && height==old_window_height ) {
+		GdkEventExpose event;
+		refresh(&event);
+	}
+}
+#endif
+
 bool
 WorkArea::refresh(GdkEventExpose*event)
 {
+#ifdef SINGLE_THREADED
+	/* resize bug workaround */
+	if (App::single_threaded) {
+		int width;
+		int height;
+		bool resize_in_progress;
+		resize_in_progress = false;
+		canvas_view->get_size(width, height);
+		//synfig::info("Size: %i, %i",width,height);
+		if (width!=old_window_width || height!=old_window_height ) {
+
+			resize_in_progress = true;
+
+			//queue second check
+			int func_id;
+			func_id=g_timeout_add_full(
+				G_PRIORITY_DEFAULT,	// priority -
+				200,			// interval - the time between calls to the function, in milliseconds (1/1000ths of a second)
+				__refresh_second_check,	// function - function to call
+				this,				// data     - data to pass to function
+				NULL);				// notify   - function to call when the idle is removed, or NULL
+		}
+		old_window_width=width;
+		old_window_height=height;
+		if (resize_in_progress){
+			if (get_updating())
+			{
+				stop_updating();
+			}
+			return true;
+		}
+	}
+#endif
+	
 	assert(get_canvas());
 
-	drawing_area->get_window()->clear();
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> draw_area_window = drawing_area->get_window();
+	if(!draw_area_window) return false;
+
+	draw_area_window->clear();
 
 	//const synfig::RendDesc &rend_desc(get_canvas()->rend_desc());
 
@@ -2615,7 +2682,7 @@ WorkArea::refresh(GdkEventExpose*event)
 		{
 			if((*iter)->get_enabled())
 				(*iter)->render_vfunc(
-					drawing_area->get_window(),
+					draw_area_window,
 					Gdk::Rectangle(&event->area)
 				);
 		}
@@ -2644,7 +2711,7 @@ WorkArea::refresh(GdkEventExpose*event)
 		drawing_frame->modify_bg(Gtk::STATE_NORMAL,Gdk::Color("#FF0000"));
 #else
 		// So let's do it in a more primitive fashion.
-		Cairo::RefPtr<Cairo::Context> cr = drawing_area->get_window()->create_cairo_context();
+		Cairo::RefPtr<Cairo::Context> cr = draw_area_window->create_cairo_context();
 		cr->save();
 
 		cr->set_source_rgb(1,0,0);
@@ -2802,6 +2869,7 @@ studio::WorkArea::async_update_preview()
 	// Setup the description parameters
 	desc.set_antialias(1);
 	desc.set_time(cur_time);
+	desc.set_render_excluded_contexts(true);
 
 	set_rend_desc(desc);
 
@@ -3056,6 +3124,10 @@ WorkArea::sync_render_preview_hook()
 void
 WorkArea::queue_scroll()
 {
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> draw_area_window = drawing_area->get_window();
+	if(!draw_area_window) return;
+
 //	const synfig::RendDesc &rend_desc(get_canvas()->rend_desc());
 
 	const synfig::Point focus_point(get_focus_point());
@@ -3076,12 +3148,18 @@ WorkArea::queue_scroll()
 		dx(round_to_int(old_x)-round_to_int(new_x)),
 		dy(round_to_int(old_y)-round_to_int(new_y));
 
-	drawing_area->get_window()->scroll(-dx,-dy);
+	draw_area_window->scroll(-dx,-dy);
 
 	if (timecode_width && timecode_height)
 	{
-		drawing_area->queue_draw_area(4,       4,    4+timecode_width,    4+timecode_height);
-		drawing_area->queue_draw_area(4-dx, 4-dy, 4-dx+timecode_width, 4-dy+timecode_height);
+		drawing_area->queue_draw_area(timecode_x,    timecode_y,    timecode_x+timecode_width,    timecode_y+timecode_height);
+		drawing_area->queue_draw_area(timecode_x-dx, timecode_y-dy, timecode_x-dx+timecode_width, timecode_y-dy+timecode_height);
+	}
+
+	if (bonesetup_width && bonesetup_height)
+	{
+		drawing_area->queue_draw_area(bonesetup_x,    bonesetup_y,    bonesetup_x+bonesetup_width,    bonesetup_y+bonesetup_height);
+		drawing_area->queue_draw_area(bonesetup_x-dx, bonesetup_y-dy, bonesetup_x-dx+bonesetup_width, bonesetup_y-dy+bonesetup_height);
 	}
 
 #ifndef USE_FRAME_BACKGROUND_TO_SHOW_EDIT_MODE
@@ -3197,6 +3275,7 @@ studio::WorkArea::queue_render_preview()
 
 	if(queued==false)
 	{
+		queued=true;
 		//synfig::info("queue_render_preview(): (re)queuing...");
 		//render_idle_func_id=g_idle_add_full(G_PRIORITY_DEFAULT,__render_preview,this,NULL);
 		render_idle_func_id=g_timeout_add_full(
@@ -3205,7 +3284,6 @@ studio::WorkArea::queue_render_preview()
 			__render_preview,	// function - function to call
 			this,				// data     - data to pass to function
 			NULL);				// notify   - function to call when the idle is removed, or NULL
-		queued=true;
 	}
 /*	else if(rendering)
 	{
@@ -3239,12 +3317,20 @@ studio::WorkArea::queue_draw_preview()
 void
 studio::WorkArea::set_cursor(const Gdk::Cursor& x)
 {
-	drawing_area->get_window()->set_cursor(x);
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> draw_area_window = drawing_area->get_window();
+	if(!draw_area_window) return;
+	
+	draw_area_window->set_cursor(x);
 }
 void
 studio::WorkArea::set_cursor(Gdk::CursorType x)
 {
-	drawing_area->get_window()->set_cursor(Gdk::Cursor(x));
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> draw_area_window = drawing_area->get_window();
+	if(!draw_area_window) return;
+	
+	draw_area_window->set_cursor(Gdk::Cursor(x));
 }
 
 //#include "iconcontroller.h"
@@ -3257,7 +3343,11 @@ studio::WorkArea::refresh_cursor()
 void
 studio::WorkArea::reset_cursor()
 {
-	drawing_area->get_window()->set_cursor(Gdk::Cursor(Gdk::TOP_LEFT_ARROW));
+	//!Check if the window we want draw is ready
+	Glib::RefPtr<Gdk::Window> draw_area_window = drawing_area->get_window();
+	if(!draw_area_window) return;
+	
+	draw_area_window->set_cursor(Gdk::Cursor(Gdk::TOP_LEFT_ARROW));
 //	set_cursor(Gdk::TOP_LEFT_ARROW);
 }
 
