@@ -54,6 +54,7 @@
 #include "dials/zoomdial.h"
 #include "duckmatic.h"
 #include "instance.h"
+#include "app.h"
 
 /* === M A C R O S ========================================================= */
 
@@ -281,6 +282,12 @@ private:
 	bool dirty;
 	bool queued;
 	bool rendering;
+	
+#ifdef SINGLE_THREADED
+	/* resize bug workaround */
+	int old_window_width;
+	int old_window_height;
+#endif
 
 	/*
  -- ** -- P U B L I C   D A T A -----------------------------------------------
@@ -325,6 +332,9 @@ public:
 	// used in renderer_timecode.cpp
 	int timecode_width, timecode_height;
 
+	// used in renderer_bonesetup.cpp
+	int bonesetup_width, bonesetup_height;
+
 	/*
  -- ** -- P R I V A T E   M E T H O D S ---------------------------------------
 	*/
@@ -514,6 +524,10 @@ public:
 
 	void done_rendering();
 
+#ifdef SINGLE_THREADED
+	/* resize bug workaround */
+	void refresh_second_check();
+#endif
 	bool refresh(GdkEventExpose*bleh=NULL);
 
 	void reset_cursor();
@@ -545,6 +559,10 @@ public:
 private:
 
 	static gboolean __render_preview(gpointer data);
+#ifdef SINGLE_THREADED
+	/* resize bug workaround */
+	static gboolean __refresh_second_check(gpointer data);
+#endif
 
 }; // END of class WorkArea
 
