@@ -40,6 +40,7 @@
 #include "actions/layerlower.h"
 #include "actions/layeradd.h"
 #include "actions/layeractivate.h"
+#include "actions/layermakebline.h"
 #include "actions/layerparamset.h"
 #include "actions/layerparamsetstatic.h"
 #include "actions/layerparamunsetstatic.h"
@@ -48,6 +49,7 @@
 #include "actions/layerencapsulate.h"
 #include "actions/layerduplicate.h"
 #include "actions/layersetdesc.h"
+#include "actions/layersetexcludefromrendering.h"
 
 #include "actions/valuenodeconstset.h"
 #include "actions/valuenodeconstsetstatic.h"
@@ -63,10 +65,18 @@
 #include "actions/valuenodedynamiclistloop.h"
 #include "actions/valuenodedynamiclistunloop.h"
 #include "actions/valuenodedynamiclistrotateorder.h"
+#include "actions/valuenodestaticlistinsert.h"
+#include "actions/valuenodestaticlistremove.h"
+#include "actions/valuenodestaticlistinsertsmart.h"
+#include "actions/valuenodestaticlistremovesmart.h"
+#include "actions/valuenodestaticlistloop.h"
+#include "actions/valuenodestaticlistunloop.h"
+#include "actions/valuenodestaticlistrotateorder.h"
 #include "actions/valuenoderename.h"
 #include "actions/valuenoderemove.h"
 
 #include "actions/valuedescset.h"
+#include "actions/valuedescsetinterpolation.h"
 #include "actions/valuedescexport.h"
 #include "actions/valuedescconvert.h"
 #include "actions/valuedescconnect.h"
@@ -168,6 +178,9 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerLower);
 	ADD_ACTION(Action::LayerAdd);
 	ADD_ACTION(Action::LayerActivate);
+	ADD_ACTION(Action::LayerMakeOutline);
+	ADD_ACTION(Action::LayerMakeAdvancedOutline);
+	ADD_ACTION(Action::LayerMakeRegion);
 	ADD_ACTION(Action::LayerParamSet);
 	ADD_ACTION(Action::LayerParamSetStatic);
 	ADD_ACTION(Action::LayerParamUnSetStatic);
@@ -176,6 +189,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerEncapsulate);
 	ADD_ACTION(Action::LayerDuplicate);
 	ADD_ACTION(Action::LayerSetDesc);
+	ADD_ACTION(Action::LayerSetExcludeFromRenderingOn);
+	ADD_ACTION(Action::LayerSetExcludeFromRenderingOff);
 
 	ADD_ACTION(Action::ValueNodeConstSet);
 	ADD_ACTION(Action::ValueNodeConstSetStatic);
@@ -191,10 +206,18 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueNodeDynamicListLoop);
 	ADD_ACTION(Action::ValueNodeDynamicListUnLoop);
 	ADD_ACTION(Action::ValueNodeDynamicListRotateOrder);
+	ADD_ACTION(Action::ValueNodeStaticListInsert);
+	ADD_ACTION(Action::ValueNodeStaticListRemove);
+	ADD_ACTION(Action::ValueNodeStaticListInsertSmart);
+	ADD_ACTION(Action::ValueNodeStaticListRemoveSmart);
+	ADD_ACTION(Action::ValueNodeStaticListLoop);
+	ADD_ACTION(Action::ValueNodeStaticListUnLoop);
+	ADD_ACTION(Action::ValueNodeStaticListRotateOrder);
 	ADD_ACTION(Action::ValueNodeRename);
 	ADD_ACTION(Action::ValueNodeRemove);
 
 	ADD_ACTION(Action::ValueDescSet);
+	ADD_ACTION(Action::ValueDescSetInterpolation);
 	ADD_ACTION(Action::ValueDescExport);
 	ADD_ACTION(Action::ValueDescConvert);
 	ADD_ACTION(Action::ValueDescConnect);
@@ -402,8 +425,9 @@ Super::perform()
 	ActionList::const_iterator iter;
 	for(iter=action_list_.begin();iter!=action_list_.end();++iter)
 	{
-		//// debug actions
-		// synfig::info("%s:%d action: '%s'", __FILE__, __LINE__, (*iter)->get_name().c_str());
+		if (getenv("SYNFIG_DEBUG_ACTIONS"))
+			synfig::info("%s:%d action: '%s'", __FILE__, __LINE__, (*iter)->get_name().c_str());
+
 		try
 		{
 			try
@@ -562,3 +586,35 @@ CanvasSpecific::get_edit_mode()const
 
 	return MODE_NORMAL;
 }
+
+//DOO static int undoable_count = 0;
+
+Undoable::Undoable():
+	active_(true)
+{
+	//DOO printf("%s:%d Undoable::Undoable() (we have %d)\n", __FILE__, __LINE__, ++undoable_count);
+}
+
+#ifdef _DEBUG
+Undoable::~Undoable() {
+	//DOO printf("%s:%d Undoable::~Undoable() (we now have %d)\n", __FILE__, __LINE__, --undoable_count);
+}
+
+void
+Undoable::ref()const
+{
+	if (getenv("SYNFIG_DEBUG_ACTION_REFCOUNT"))
+		printf("%s:%d %lx   ref undoable %*s -> %2d\n", __FILE__, __LINE__, uintptr_t(this), (count()*2), "", count()+1);
+
+	Base::ref();
+}
+
+bool
+Undoable::unref()const
+{
+	if (getenv("SYNFIG_DEBUG_ACTION_REFCOUNT"))
+		printf("%s:%d %lx unref undoable %*s%2d <-\n", __FILE__, __LINE__, uintptr_t(this), ((count()-1)*2), "", count()-1);
+
+	return Base::unref();
+}
+#endif
