@@ -2,7 +2,7 @@
 /*!	\file activepointremove.cpp
 **	\brief Template File
 **
-**	$Id: activepointremove.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointRemove);
-ACTION_SET_NAME(Action::ActivepointRemove,"activepoint_remove");
+ACTION_SET_NAME(Action::ActivepointRemove,"ActivepointRemove");
 ACTION_SET_LOCAL_NAME(Action::ActivepointRemove,N_("Remove Activepoint"));
 ACTION_SET_TASK(Action::ActivepointRemove,"remove");
 ACTION_SET_CATEGORY(Action::ActivepointRemove,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointRemove,0);
 ACTION_SET_VERSION(Action::ActivepointRemove,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointRemove,"$Id: activepointremove.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointRemove,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
