@@ -2,7 +2,7 @@
 /*!	\file activepointsetoff.cpp
 **	\brief Template File
 **
-**	$Id: activepointsetoff.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -54,13 +54,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointSetOff);
-ACTION_SET_NAME(Action::ActivepointSetOff,"activepoint_set_off");
+ACTION_SET_NAME(Action::ActivepointSetOff,"ActivepointSetOff");
 ACTION_SET_LOCAL_NAME(Action::ActivepointSetOff,N_("Mark Activepoint as \"Off\""));
 ACTION_SET_TASK(Action::ActivepointSetOff,"set_off");
 ACTION_SET_CATEGORY(Action::ActivepointSetOff,Action::CATEGORY_ACTIVEPOINT|Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ActivepointSetOff,-9);
 ACTION_SET_VERSION(Action::ActivepointSetOff,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetOff,"$Id: activepointsetoff.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointSetOff,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
