@@ -2,7 +2,7 @@
 /*!	\file activepointsetsmart.cpp
 **	\brief Template File
 **
-**	$Id: activepointsetsmart.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,13 +53,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointSetSmart);
-ACTION_SET_NAME(Action::ActivepointSetSmart,"activepoint_set_smart");
+ACTION_SET_NAME(Action::ActivepointSetSmart,"ActivepointSetSmart");
 ACTION_SET_LOCAL_NAME(Action::ActivepointSetSmart,N_("Set Activepoint (Smart)"));
 ACTION_SET_TASK(Action::ActivepointSetSmart,"set");
 ACTION_SET_CATEGORY(Action::ActivepointSetSmart,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSetSmart,0);
 ACTION_SET_VERSION(Action::ActivepointSetSmart,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetSmart,"$Id: activepointsetsmart.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointSetSmart,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
