@@ -46,7 +46,7 @@ using namespace Action;
 
 ACTION_INIT(Action::GroupRemove);
 ACTION_SET_NAME(Action::GroupRemove,"GroupRemove");
-ACTION_SET_LOCAL_NAME(Action::GroupRemove,N_("Remove Group"));
+ACTION_SET_LOCAL_NAME(Action::GroupRemove,N_("Remove Set"));
 ACTION_SET_TASK(Action::GroupRemove,"remove");
 ACTION_SET_CATEGORY(Action::GroupRemove,Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupRemove,0);
@@ -69,8 +69,8 @@ Action::GroupRemove::get_param_vocab()
 	ParamVocab ret(Action::CanvasSpecific::get_param_vocab());
 
 	ret.push_back(ParamDesc("group",Param::TYPE_STRING)
-		.set_local_name(_("Group"))
-		.set_desc(_("Name of the Group to remove"))
+		.set_local_name(_("Set"))
+		.set_desc(_("Name of the Set to remove"))
 	);
 
 	return ret;
