@@ -2,7 +2,7 @@
 /*!	\file layermove.cpp
 **	\brief Template File
 **
-**	$Id: layermove.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerMove);
-ACTION_SET_NAME(Action::LayerMove,"layer_move");
+ACTION_SET_NAME(Action::LayerMove,"LayerMove");
 ACTION_SET_LOCAL_NAME(Action::LayerMove,N_("Move Layer"));
 ACTION_SET_TASK(Action::LayerMove,"move");
 ACTION_SET_CATEGORY(Action::LayerMove,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerMove,0);
 ACTION_SET_VERSION(Action::LayerMove,"0.0");
-ACTION_SET_CVS_ID(Action::LayerMove,"$Id: layermove.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerMove,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
