@@ -47,7 +47,7 @@ using namespace Action;
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerRemove);
 ACTION_SET_NAME(Action::LayerRemove,"LayerRemove");
-ACTION_SET_LOCAL_NAME(Action::LayerRemove,N_("Remove Layer"));
+ACTION_SET_LOCAL_NAME(Action::LayerRemove,N_("Delete Layer"));
 ACTION_SET_TASK(Action::LayerRemove,"remove");
 ACTION_SET_CATEGORY(Action::LayerRemove,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerRemove,0);
@@ -67,7 +67,7 @@ Action::LayerRemove::LayerRemove()
 synfig::String
 Action::LayerRemove::get_local_name()const
 {
-	return get_layer_descriptions(layer_list, _("Remove Layer"), _("Remove Layers"));
+	return get_layer_descriptions(layer_list, _("Delete Layer"), _("Delete Layers"));
 }
 
 Action::ParamVocab
