@@ -171,7 +171,9 @@ Action::ValueDescExport::prepare()
 		if(!value_desc.is_const())
 			throw Error(_("Can only export Canvas when used as constant parameter"));
 		Canvas::Handle canvas(value_desc.get_value().get(Canvas::Handle()));
-		if (canvas) canvas=canvas->clone();
+
+		// clone canvas (all code that clones a canvas has this comment)
+		if (canvas) canvas=canvas->clone(GUID(), true);
 
 		Action::Handle action(CanvasAdd::create());
 
