@@ -394,7 +394,7 @@ Action::ValueDescLink::prepare()
 			if( (value_desc.get_scalar()*link_scalar<0 || link_opposite) && (link_is_scaled==false))
 			{
 				//Let's create a Scale Value Node
-				synfig::ValueNode::Handle scale_value_node=synfig::LinkableValueNode::create("scale",iter->get_value(time));
+				synfig::ValueNode::Handle scale_value_node=synfig::LinkableValueNode::create("scale",iter->get_value(time),get_canvas());
 				if(!scale_value_node)
 					throw Error(Error::TYPE_BUG);
 				scale_value_node->set_parent_canvas(get_canvas());
