@@ -52,6 +52,8 @@
 #include <synfig/importer.h>
 #include <synfig/guidset.h>
 
+#include <synfig/context.h>
+
 #include "canvasinterface.h"
 #include "instance.h"
 
@@ -181,6 +183,162 @@ CanvasInterface::get_mode()const
 }
 
 
+void
+CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
+{
+	if(!layer)
+		return;
+
+	synfig::Canvas::Handle canvas( layer->get_canvas() );
+	if (!canvas)
+		return;
+
+	synfig::String name( layer->get_name() );
+
+	ValueBase p;
+	p=layer->get_param("fg");
+	p.set(synfigapp::Main::get_outline_color());
+	if(layer->set_param("fg",p))
+	{
+		p=layer->get_param("bg");
+		p.set(synfigapp::Main::get_outline_color());
+		layer->set_param("bg",p);
+	}
+	else if (name == "outline" || name == "advanced_outline")
+	{
+		p=layer->get_param("color");
+		p.set(synfigapp::Main::get_outline_color());
+		layer->set_param("color",p);
+	}
+	else
+	{
+		p=layer->get_param("color");
+		p.set(synfigapp::Main::get_fill_color());
+		layer->set_param("color",p);
+	}
+	// by default, new advanced outline layers are not homogeneous
+	if(name=="advanced_outline")
+	{
+		p=layer->get_param("homogeneous");
+		p.set(false);
+		layer->set_param("homogeneous",p);
+	}
+	p=layer->get_param("width");
+	p.set(synfigapp::Main::get_bline_width().units(get_canvas()->rend_desc()));
+	layer->set_param("width",p);
+	
+	p=layer->get_param("gradient");
+	p.set(synfigapp::Main::get_gradient());
+	layer->set_param("gradient",p);
+	
+	if(name!="zoom")
+	{
+		p=layer->get_param("amount");
+		p.set(synfigapp::Main::get_opacity());
+		layer->set_param("amount",p);
+	}
+	if(synfigapp::Main::get_blend_method() != Color::BLEND_BY_LAYER)
+	{
+		p=layer->get_param("blend_method");
+		p.set(synfigapp::Main::get_blend_method());
+		layer->set_param("blend_method",p);
+	}
+
+
+	{
+		// Grab the layer's list of parameters
+		Layer::ParamList paramlist=layer->get_param_list();
+		Layer::ParamList::iterator iter;
+
+		// loop through the static parameters
+		for(iter=paramlist.begin();iter!=paramlist.end();++iter)
+		{
+			ValueNode::Handle value_node;
+
+			// if we find any which are list values then make them
+			// into dynamic list valuenodes, unless every element of
+			// the list is a blinepoint, in which case convert it to a
+			// bline
+			if(iter->second.get_type()==ValueBase::TYPE_LIST)
+			{
+				// check whether it's a list of blinepoints or widthpoints only
+				vector<ValueBase> list(iter->second.get_list());
+				if (list.size())
+				{
+					vector<ValueBase>::iterator iter2 = list.begin();
+					ValueBase::Type type(iter2->get_type());
+					for (iter2++; iter2 != list.end(); iter2++)
+						if (iter2->get_type() != type)
+							break;
+					if (iter2 == list.end())
+					{
+						if (type == ValueBase::TYPE_BLINEPOINT)
+						{
+							value_node=LinkableValueNode::create("bline",iter->second,canvas);
+							ValueNode_BLine::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+						}
+						else if (type == ValueBase::TYPE_BONE)
+						{
+							if (getenv("SYNFIG_USE_DYNAMIC_LIST_FOR_BONES"))
+							{
+								value_node=LinkableValueNode::create("dynamic_list",iter->second,canvas);
+								ValueNode_DynamicList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+							else // this is the default
+							{
+								value_node=LinkableValueNode::create("static_list",iter->second,canvas);
+								ValueNode_StaticList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+						}
+						else if (type == ValueBase::TYPE_VECTOR)
+						{
+							if (getenv("SYNFIG_USE_STATIC_LIST_FOR_VECTORS"))
+							{
+								value_node=LinkableValueNode::create("static_list",iter->second,canvas);
+								ValueNode_StaticList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+							else // this is the default
+							{
+								value_node=LinkableValueNode::create("dynamic_list",iter->second,canvas);
+								ValueNode_DynamicList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+						}
+					}
+					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
+						if (iter2->get_type() != ValueBase::TYPE_WIDTHPOINT)
+							break;
+					if (iter2 == list.end())
+					{
+						value_node=LinkableValueNode::create("wplist",iter->second, canvas);
+						ValueNode_WPList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+					}
+					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
+						if (iter2->get_type() != ValueBase::TYPE_DASHITEM)
+							break;
+					if (iter2 == list.end())
+					{
+						value_node=LinkableValueNode::create("dilist",iter->second, canvas);
+						ValueNode_DIList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+					}
+				}
+				// it has something else so just insert the dynamic list
+				if (!value_node)
+					value_node=LinkableValueNode::create("dynamic_list",iter->second,canvas);
+			}
+			// otherwise, if it's a type that can be converted to
+			// 'composite' (other than the types that can be radial
+			// composite) then do so
+			else if(LinkableValueNode::check_type("composite",iter->second.get_type()) &&
+					 (iter->second.get_type()!=ValueBase::TYPE_COLOR &&
+					  iter->second.get_type()!=ValueBase::TYPE_VECTOR))
+				value_node=LinkableValueNode::create("composite",iter->second,canvas);
+
+			if(value_node)
+				layer->connect_dynamic_param(iter->first,value_node);
+		}
+	}
+}
+
 
 Layer::Handle
 CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas, int depth)
@@ -207,7 +365,7 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 			String name = strprintf(_("Index %d"), i);
 			try
 			{
-				canvas->find_value_node(name);
+				canvas->find_value_node(name, true);
 			}
 			catch (Exception::IDNotFound x)
 			{
@@ -219,85 +377,7 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 	layer->set_canvas(canvas);
 
 	// Apply some defaults
-	if(layer->set_param("fg",synfigapp::Main::get_outline_color()))
-		layer->set_param("bg",synfigapp::Main::get_fill_color());
-	else if (name == "outline" || name == "advanced_outline")
-		layer->set_param("color",synfigapp::Main::get_outline_color());
-	else
-		layer->set_param("color",synfigapp::Main::get_fill_color());
-	// by default, new advanced outline layers are not homogeneous
-	if(name=="advanced_outline")
-		layer->set_param("homogeneous", false);
-
-	layer->set_param("width",synfigapp::Main::get_bline_width().units(get_canvas()->rend_desc()));
-	layer->set_param("gradient",synfigapp::Main::get_gradient());
-	if(name!="zoom")
-		layer->set_param("amount",synfigapp::Main::get_opacity());
-	if(synfigapp::Main::get_blend_method() != Color::BLEND_BY_LAYER)
-		layer->set_param("blend_method",synfigapp::Main::get_blend_method());
-
-	{
-		// Grab the layer's list of parameters
-		Layer::ParamList paramlist=layer->get_param_list();
-		Layer::ParamList::iterator iter;
-
-		// loop through the static parameters
-		for(iter=paramlist.begin();iter!=paramlist.end();++iter)
-		{
-			ValueNode::Handle value_node;
-
-			// if we find any which are list values then make them
-			// into dynamic list valuenodes, unless every element of
-			// the list is a blinepoint, in which case convert it to a
-			// bline
-			if(iter->second.get_type()==ValueBase::TYPE_LIST)
-			{
-				// check whether it's a list of blinepoints or widthpoints only
-				vector<ValueBase> list(iter->second.get_list());
-				if (list.size())
-				{
-					vector<ValueBase>::iterator iter2;
-					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
-						if (iter2->get_type() != ValueBase::TYPE_BLINEPOINT)
-							break;
-					if (iter2 == list.end())
-					{
-						value_node=LinkableValueNode::create("bline",iter->second);
-						ValueNode_BLine::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
-					}
-					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
-						if (iter2->get_type() != ValueBase::TYPE_WIDTHPOINT)
-							break;
-					if (iter2 == list.end())
-					{
-						value_node=LinkableValueNode::create("wplist",iter->second);
-						ValueNode_WPList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
-					}
-					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
-						if (iter2->get_type() != ValueBase::TYPE_DASHITEM)
-							break;
-					if (iter2 == list.end())
-					{
-						value_node=LinkableValueNode::create("dilist",iter->second);
-						ValueNode_DIList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
-					}
-				}
-				// it has something else so just insert the dynamic list
-				if (!value_node)
-					value_node=LinkableValueNode::create("dynamic_list",iter->second);
-			}
-			// otherwise, if it's a type that can be converted to
-			// 'composite' (other than the types that can be radial
-			// composite) then do so
-			else if(LinkableValueNode::check_type("composite",iter->second.get_type()) &&
-					 (iter->second.get_type()!=ValueBase::TYPE_COLOR &&
-					  iter->second.get_type()!=ValueBase::TYPE_VECTOR))
-				value_node=LinkableValueNode::create("composite",iter->second);
-
-			if(value_node)
-				layer->connect_dynamic_param(iter->first,value_node);
-		}
-	}
+	apply_layer_param_defaults(layer);
 
 	// Action to add the layer
 	Action::Handle 	action(Action::LayerAdd::create());
@@ -845,10 +925,16 @@ CanvasInterface::auto_export(const ValueDesc& /*value_desc*/)
 bool
 CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value)
 {
+	ValueBase old_value;
+	old_value = value_desc.get_value(get_time());
+
 	// If this isn't really a change, then don't bother
-	if(new_value==value_desc.get_value(get_time()))
+	if(new_value==old_value)
 		return true;
 
+	// New value should inherit all properties of original ValueBase (static, etc...)
+	new_value.copy_properties_of(old_value);
+
 	// If this change needs to take place elsewhere, then so be it.
 	if(value_desc.get_canvas())
 	{
@@ -1004,9 +1090,9 @@ CanvasInterface::find_important_value_descs(synfig::Canvas::Handle canvas,std::v
 			ret+=_process_value_desc(ValueDesc(canvas,(*iter)->get_id()),out,guid_set);
 	}
 
-	Canvas::const_iterator iter;
+	IndependentContext iter;
 
-	for(iter=canvas->begin();iter!=canvas->end();++iter)
+	for(iter=canvas->get_independent_context();iter!=canvas->end();++iter)
 	{
 		Layer::Handle layer(*iter);
 
