@@ -31,10 +31,14 @@
 
 #include "main.h"
 #include "action.h"
+
+#ifndef WIN32
 #include <pwd.h>
+#endif
 
 #include <synfig/color.h>
 #include <synfig/gradient.h>
+#include <glibmm.h>
 
 #include <ETL/trivial>
 
@@ -110,7 +114,13 @@ synfigapp::Main::Main(const synfig::String &basepath, synfig::ProgressCallback *
 	// Add initialization after this point
 
 #ifdef ENABLE_NLS
-	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+	String locale_dir;
+	locale_dir = etl::dirname(basepath)+ETL_DIRECTORY_SEPARATOR+"share"+ETL_DIRECTORY_SEPARATOR+"locale";
+#ifdef WIN32
+	locale_dir = Glib::locale_from_utf8(locale_dir);
+#endif
+	
+	bindtextdomain(GETTEXT_PACKAGE, locale_dir.c_str() );
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif
 
@@ -427,7 +437,7 @@ synfigapp::Main::get_user_app_directory()
 	String dir;
 	//! \todo do we need something like Glib::locale_from_utf8()?  (bug #1837445)
 #ifdef WIN32
-	dir = String(getenv("HOMEDRIVE"))+ETL_DIRECTORY_SEPARATOR+getenv("HOMEPATH");
+	dir = String(getenv("HOMEDRIVE"))+getenv("HOMEPATH");
 #else
 	struct passwd* pwd = getpwuid(getuid());
 	if (pwd)
